version 12.1
clear
set more off

// cd "T:\Labor_economics\ES\ES2\Datasets"

cd "D:\Study\CERGE-EI\TA\Labor_economics\ES\ES2\Datasets"

* ### Patterns of missing values ###
* ##################################

* Create a small dataset

import excel using Missing_values.xlsx, firstrow clear
describe

* #####################################################################
* ### 1. Number of missing values vs. number of non missing values ###

* The first thing to do to examine the dataset for missing values is to determine which variables have a lot of missing values. 

* There is a small Stata program called "mdesc" that counts the number of missing values in both numeric and character variables. 
// You can download "mdesc" from within Stata by typing "findit mdesc"

* Run "mdesc" for one or more variables.

mdesc

// Now we know the number of missing values in each variable. 
// For instance, variable salepric has four missing values and saltoapr has two missing values.

* #################################################################
* ### 2. Obtaining the number of missing values per observation ###

* We can also look at the distribution of missing values across observations. 
// The code below creates a variable called "nmis" that gives the number of missing values for each observation. 
// The function "rmiss2()" used here is an extension to the egen function "rmiss()". 
// It counts the number of missing values in the varlist. 
// rmiss2() accepts both string and numeric variables. (Stata's rmiss() only accepts numeric variables.) 

// You can download rmiss2() over the internet from within Stata by typing "findit rmiss2".

egen nmis=rmiss2(landval improval totval salepric saltoapr)

* Below we tabulate the variable we just created. 

tab nmis

// Looking at the frequency table we know that there are four observations with no missing values, 
// nine observations with one missing values, one observation with two missing values and one observation with three missing values.


* #####################################
* ### 3. Patterns of missing values ###

* To look at the patterns of missing values, you can download "mvpatterns" over the internet from within Stata by typing "findit mvpatterns"
// The command "mvpatterns" produces output for all variables in the dataset, for missing data patterns across a subset of variables, 
// a variable list can be included, for example: "mvpatterns landval improval totval".

mvpatterns

// The first table lists the variables, their storage type (type), the number of observations (obs), 
// the number of missing values (mv), and the variable label if the variables has one. 

// The second table contains the information on the pattern of missing values. 
// The first block of columns in the output shows the patterns of missing data. 
// Within the block, each variable is represented by a column, 
// a "+" indicates that values of that variable are present in a given missing data pattern, 
// a "." indicates that they are missing. 
// The columns follow the same order as the variable list in the first table, 
// so that the first column in the output below represents landval, the second improval, and so on. 

// The missing data patterns are listed in descending frequency, here the most common missing data pattern is complete data ("+++++"). 
// The table also shows the number of missing values in that pattern (_mv), and the number of cases with that missing data pattern (_freq). 
// Based on the information in the second table we know that there are four observations with no missing values, 
// two cases missing on just the variable salepric, and one observation with missing values on improval, salepric and saltoapr, and so on.


* #########################################################
* ### 4. When all the variables of interest are numeric ###

* The examples above all work regardless of whether the variables of interest 
// (i.e. the variables whose missing data patterns you want to examine) are numeric or string. 

* When all of the variables you wish to check for missing values are numeric we can use a program called "misschk"
// to simplify the steps of examining the missing data in our dataset. 

// (Note: numeric variables include those with value labels that are strings, as long as the actual values of the variables are stored as numbers.) 

// You can download "misschk" from within Stata by typing "findit misschk"

misschk landval improval totval salepric saltoapr, gen(miss)

// We have listed all five of the variables in our dataset in the variable list after the misschk command. 
// However, we could have just left the list of variables blank (i.e. used only misschk , gen(miss) instead), 
// if we had, "misschk" would have run using all the variables in our dataset. 

// The "gen(miss)" option tells "misschk" that we want it to create two new variables, both of which start with "miss". 
// These two variables will be named "misspattern" and "missnumber". 
// The variable "misspattern" indicates which of the missing data patterns each case follows. 
// The variable "missnumber" indicates the number of missing values for each case.

* The output for misschk consists of three tables. 
// The first table lists the number of missing values, as well as percent missing for each variable, 
// this is similar to the table produced by "mdesc" in part 1 above. 
// This table also contains a column labeled "#" which assigns each variable a number that is used to identify the variable later on in the output. 

// The second table shows the distribution of missing values. 
// The pattern of missingness is described using the variable numbers from the first table, and underscores ("_"). 
// The numbers indicate which variables are missing in that pattern, the underscores represent non-missing observations. 
// For example, from the second table we see that two cases have missing values on variable 1 (landval), 
// but complete data on all other variables, and that one case is missing data on variables 2, 4, and 5. 
// The bottom row shows that four cases are not missing any values at all (all underscores). 
// This table shows the same information generated in part three above, but in a slightly different format. 
// The missing data pattern for each case is described in the variable misspattern. 

// Finally, the third table shows the distribution of the number of missing values per case. 
// This is the same information discussed above in part 2. The number of variables each case is missing is also contained in the variable missnumber.
