* Plan

// 0. Show how to work with Stat/Transfer
// 1. Important extra topics form the Data management - Part I
// 2. Tasks form empirical assignment - summary satistics and tables, missing values and outliers
// 3. Current session - Summary statistics and tables, identification of missing values and their patterns
// 4. Upcoming session - Graphs and outliers.
// 5. Agree on the lecture on Web of Sciense literature search: http://apps.webofknowledge.com/

version 12.1
clear all
set more off

* # Setting  working directory to whereever stata is working from 

// cd "T:\Labor_economics\ES\ES2\Datasets"

cd "D:\Study\CERGE-EI\TA\Labor_economics\ES\ES2\Datasets"

* ### 4. Summary Statistics and Tables ###
* ########################################

* The summary of statistics is best divided into two cases - case of categorical variables and
// case of continuous variables; lets start with the more general case of continuous varaibles

* ########################################################
* ### 4.1 Summary Statistics for Measurement (continuous) Variables ###

* Dataset electricity.dta contains information on electricity consumption in U.S. states
use electricity.dta, clear
describe

* ### summarize

* To find the basic statistics of per capita electricity use (elcap), type
summarize elcap

* To see more detailed summary statistics, type
summarize elcap, detail

// "summarize, detail" output includes basic statistics plus the following:
* # Percentiles: Notably the first quartile (25th percentile = 10,359), median (50th percentile = 13,388), and third quartile (75th percentile = 16,117). 
// Because many samples do not divide evenly into quarters or other standard fractions, these percentiles are approximations.
/* A percentile is a measure indicating the value below which a given percentage of observations in a group of observations fall. */
* # Four smallest and four largest values, where outliers might show up.
* # Sum of weights: the summarize command permits frequency weights or fweight. For explanations see "help weight".
* # Variance: Standard deviation squared.
* # Skewness: The direction and degree of asymmetry. A perfectly symmetrical distribution has skewness = 0. 
// Positive skew (heavier right tail) results in skewness > 0; negative skew (heavier left tail) results in skewness < 0.
* # Kurtosis: Tail weight. A normal (Gaussian) distribution is symmetrical with kurtosis = 3. 
// If a symmetrical distribution has heavier-than-normal tails (is sharply peaked), then kurtosis > 3.
// Kurtosis < 3 indicates lighter-than-normal tails.

* ### tabstat

* The "tabstat" command provides a more flexible alternative to summarize. We can specify just which summary statistics we want to see. 
// Type "help tabstat" to see a complete list.
tabstat elcap, stats(mean min max)

* With a by(varname) option, tabstat constructs a table containing summary statistics for each value of varname. 
// The following example gives means, minimum and maximum for per capita electricity use, separately for each of four U.S. census regions. 
tabstat elcap, stats(mean min max) by(region4)

* ##########################################################
* ### 4.2 Frequency Tables and Two-Way Cross-Tabulations ###

* The summary statistics described above apply mainly to measurement variables. 
* Categorical variables require different approaches, often starting with simple one- or two-way tables. 
// Using such tables we return to the Granite State Poll data, Granite2011_6.dta. 
// One question (trackus) asked whether people think the U.S. is headed in the right direction, or is on the wrong track. 

* ### tabulate

use Granite2011_6.dta, clear
tabulate trackus

// "tabulate" can produce frequency distributions for variables that have thousands of values. 

* "tabulate" followed by two variable names creates a two-way cross-tabulation. 
// For example, here is a cross-tabulation of trackus by educ (respondents level of education):

tabulate educ trackus

// The first-named variable forms the rows, and the second forms columns in the resulting table.

* "tabulate" has a number of options that are useful with two-way tables. 
// For example, the option missing requests that missing values be included among the rows or columns of the table. 
// "tabulate" can also save frequencies and variables names as matrices. 
// Type "help tabulate" for list of options with details.


* ###########################################################
* ### 4.3 Multiple Tables and Multi-Way Cross-Tabulations ###

* With surveys and other large datasets, we sometimes need frequency distributions of many different variables. 
// Instead of asking for each table separately, for example by typing tabulate tparty, 
// then tabulate obama, and finally tabulate trackus, we could simply use another specialized command, "tab1":

tab1 tparty obama trackus

// To produce one-way frequency tables for each variable from tparty through trackus in this dataset (the maximum is 30 variables at one time), type

tab1 tparty-trackus

* "tab2" creates multiple two-way tables. 
// For example, the following command crosstabulates every two-way combination of the listed variables:

tab2 tparty obama trackus

// tab1 and tab2 offer the same options as tabulate.

* To form multi-way contingency tables, it is possible to use tabulate with a by prefix.

tab obama college, col nof

// One way to make a three-way cross-tabulation of the obama/college relationship by gender is to use sort and the by: prefix. 
// This produces two-way tables with the same layout as above, but separately for males and females.

by sex, sort: tab obama college, col nof

* To get a four-way crosstabulation of obama by college, with separate sub-tables for married and unmarried men and women, 
// we could type the commands (results not shown):

by sex married, sort: tab obama college, col nof

* ### table

* Alternative way to produce multi-way tables is through Stata's general table-making command, "table". 
// This command has many options, only a few of which are illustrated here. 
// To construct a two-way table of obama by college, with frequencies in each cell, type

table obama college, contents(freq)

* If we specify a third categorical variable, it forms the supercolumns of a three-way table:

table obama college sex, contents(freq)

// More complicated tables require the by( ) option, which allows up to four supperrow variables.
// "table" thus can produce up to seven-way tables: one row, one column, one supercolumn, and up to four superrows. 
// Here is a four-way example:

table obama college sex, contents(freq) by(married)

// The table examples above all place frequencies in the cells, but table permits statistical summaries as well. 
// Here is a four-way table, obama * college * sex * married, in which each cell contains the mean age for that combination of characteristics. 

table obama college sex, contents(mean age) by(married)

// For example, we see that the 34 non-college, unmarried men who did not vote for Obama have a mean age of 46.6 years.

* The contents( ) option of table specifies what statistics the tables cells contain. 
// The choices include not just frequency or mean, but also standard deviation, minimum, maximum, median, range, percentiles and other summaries. 
// Type help table for a full list.


* #################################################################
* ### 4.4 Tables of Means, Medians and Other Summary Statistics ###

* "tabulate" produces tables of means and standard deviations within categories of the tabulated variable. 
// For the remaining examples in this chapter, we return to the data on electricity consumption in U.S. states. 
// "tabulate" gives us one way to view summary statistics of per capita electricity consumption (elcap) for each of the 9 U.S. census divisions (region9):

use electricity.dta, clear
tabulate region9, summ(elcap)

* We could also use tabulate to form a two-way table of means using the 9 census divisions and 4 census regions:

tabulate region9 region4, summ(elcap) mean

* The means option above called for a table containing only means. 
// Otherwise we get a bulkier table with means, standard deviations and frequencies within each cell.

* The more flexible "table" command can build up to seven-way tables containing means, standard deviations, sums, medians or other statistics. 
// For illustration, here is a one-way table showing mean and standard deviation of per capita electricity use 
// and also the median and interquartile range of population, within each census division.

table region9, contents (mean elcap sd elcap median pop iqr pop)

/* important part of summary statistics, and many estimation stata commands in general, is accessing results of the commands, 
so that they can be further used in future commands; 
every stata estimation command has list of values which is stores as results; 
if the command is such that it describes data but does not estimate parameters, so called r-class command,
and its results are stored in r() scalars; the whole list can be displayed after the command "return list", 
or viewed in the help widnow */ 
  
/* it is crucial to recognize that stata stores the reuls of the last r-class commmand only -
if we run new estimation command, new return list is stored; 
therefore  if we want to use the results in future we have to immediately store them as new scalars/matrices */


* #####################################
* ### 4.5 Explanatory data analysis ###

* The "stem-and-leaf display" is one of the explanatory data analysis methods.
// It is a graphical arrangement of ordered data values in which initial digits form the stems 
// and following digits for each observation make up the leaves

use electricity.dta, clear
stem elcap

// In this display the lowest per capita electricity value, 6,721 (California), appears as a 721 leaf on the 6*** stem. 
// The highest, 27,457 (Wyoming), appears as a 457 leaf on the 27*** stem.
// "stem" automatically chooses values for the stems, but can override this with a lines( ) option.
// Type help stem for information about this option and others.

// The "stem-and-leaf display" can be useful when looking for the outliers
